<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!-- Jo Carter (jxc04m) Coursework 1 IAW -->

<!-- This is the template for the main page.  It displays a different layout depending on which page is requesting it. -->

<xsl:template match="moduleml">

<html>

<title>Computer Science : 
    <xsl:value-of select="module/@code"/>
</title>

<link rel="stylesheet" type="text/css" href="jxc04m.css"/>

<body>

<img src="tsglogo.gif" alt="TSG logo" width="226" height="20"/>

<xsl:choose>
    <xsl:when test="count(module)=1">
        <xsl:apply-templates select="module"/>
    </xsl:when>
    <xsl:otherwise>
        <xsl:apply-templates select="headline|subtitle|datetable|contentspage"/>
    </xsl:otherwise>
</xsl:choose>

<hr />

<xsl:variable name="responsible" select="@responsible"/>

<p>Last updated: <xsl:value-of select="@updated"/><br />
   Version <xsl:value-of select="@version"/><br />
   Please contact me with any comments or additions: <a href="mailto:{$responsible}@cs.nott.ac.uk">
        <xsl:value-of select="$responsible"/>@cs.nott.ac.uk</a></p>

<hr />

<p>
    <a href="http://validator.w3.org/check/referer">
    <img src="http://www.w3.org/Icons/valid-xhtml10" alt="Valid Strict XHTML 1.0!" height="31px" width="88px"/>
    </a>

    <a href="http://jigsaw.w3.org/css-validator/">
    <img src="http://jigsaw.w3.org/css-validator/images/vcss.gif"  alt="Valid CSS" height="31px" width="88px"/>
    </a>
</p>

</body>
</html>

</xsl:template>


<!-- The headline and subtitle elements for table.xml -->

<xsl:template match="headline">

<h1><xsl:value-of select="."/></h1>

</xsl:template>

<xsl:template match="subtitle">

<p><xsl:value-of select="."/></p>

</xsl:template>

<!-- This template displays the talbes containing the important dates on table.xml -->

<xsl:template match="datetable">

<xsl:for-each select=".">

    <table>

    <tr><td colspan="2"><b><xsl:value-of select="leftcolumntitle"/></b></td></tr>

        <xsl:for-each select="daterow">
            <tr><td class="title"><xsl:value-of select="leftcolumn"/></td>
            <td><xsl:value-of select="date"/></td></tr>
        </xsl:for-each>

    </table><br />

</xsl:for-each>

</xsl:template>

<!-- These templates displays the last part of table.xml, including sorting the modules by semester and module type. -->

<xsl:template match="contentspage">

<xsl:apply-templates/>

<hr />

<p><b>* compulsory module</b></p>

</xsl:template>

<xsl:template match="semester">

<xsl:for-each select=".">

    <xsl:variable name="semester" select="@value"/>

    <h2>Semester <xsl:value-of select="$semester"/></h2>
    
    <xsl:for-each select="/moduleml/moduletable/record">

        <xsl:sort select="@short"/>

        <xsl:variable name="short" select="@short"/>

        <xsl:if test="count(/moduleml/contentspage/semester[$semester=@value]/module[$short=@type]) &gt; 0">
            
            <h4><xsl:value-of select="."/></h4>
           
            <xsl:for-each select="/moduleml/contentspage/semester[$semester=@value]/module[$short=@type]">

                <xsl:choose>
                    <xsl:when test="(@compulsory)='true'">
                        <p class="compulsory"><a href="{@code}.xml">
                        <xsl:value-of select="@code"/></a> *</p>
                    </xsl:when>
                    <xsl:otherwise>
                        <p><a href="{@code}.xml">
                        <xsl:value-of select="@code"/></a></p>
                    </xsl:otherwise>
                </xsl:choose>
               
            </xsl:for-each>
                
        </xsl:if>
            
    </xsl:for-each>

</xsl:for-each>

</xsl:template>


<!-- This is the main template for the separate module pages. -->

<xsl:template match="module">

<h1>
    <xsl:value-of select="@title"/>
</h1>

<ol>

    <h2>Introduction</h2>

    <li><b>Title of Module:</b><br />
        <xsl:value-of select="@title"/>
    </li>

    <li><b>Module Code Number:</b><br />
        <xsl:value-of select="@code"/>
    </li>

    <xsl:apply-templates select="requirements|further"/>

</ol>

</xsl:template>

<!-- These templates format the rest of the items on the module page. -->

<!-- I've grouped the requirements in one segment because if the tag doesn't exist then it won't apply the template. -->

<xsl:template match="requirements">

<h2>Requirements</h2>

    <li><b>Co-requisites:</b>
        <xsl:if test="count(co-requisites)=0">
            <br />none
        </xsl:if>
        <xsl:if test="count(co-requisites) &gt; 0">
            <xsl:for-each select="co-requisites/modulecode">
                <br />
                <a href="{.}.xml"><xsl:value-of select="."/></a>
            </xsl:for-each>
        </xsl:if>
    </li>

    <li><b>Pre-requisites:</b>
        <xsl:if test="count(pre-requisites)=0">
            <br />none
        </xsl:if>
        <xsl:if test="count(pre-requisites) &gt; 0">
            <xsl:for-each select="pre-requisites/modulecode">
                <br />
                <a href="{.}.xml"><xsl:value-of select="."/></a>
            </xsl:for-each>
        </xsl:if>
    </li>

</xsl:template>

<xsl:template match="further">

    <h2>Further details</h2>

    <xsl:apply-templates/>

</xsl:template>

<!-- These are all the 'further' templates -->

<xsl:template match="target">

    <li><b>Target Group:</b>
        <xsl:for-each select="group">
            <br />
            <xsl:value-of select="."/>
        </xsl:for-each>
    </li>

</xsl:template>

<xsl:template match="content">

    <li><b>Summary of Content:</b><br />
        <xsl:apply-templates/>
    </li>

</xsl:template>

<!-- The typo is to match the output.pdf file, should be spelt assessment -->

<xsl:template match="activities">

    <li><b>Module activities</b><br />
        <xsl:value-of select="."/><br />
        Tutor led hours: <xsl:value-of select="@tutorlead"/><br />
        Student directed hours: <xsl:value-of select="@student"/><br />
        Assesment: <xsl:value-of select="@assessment"/><br />
    </li>

</xsl:template>

<xsl:template match="assessment">

    <li><b>Assessment details:</b><br />
        <xsl:value-of select="."/>
    </li>

</xsl:template>

<xsl:template match="convener">

    <li><b>Module convener:</b><br />
        <xsl:if test="count(link)=0">
            <xsl:value-of select="."/>
        </xsl:if>
        <xsl:if test="count(link) &gt; 0">
            <a href="{link/@target}"><xsl:value-of select="."/></a>
        </xsl:if>
    </li>

</xsl:template>

<xsl:template match="admindetails">

    <li><b>Administration details:</b><br />
        <xsl:value-of select="."/>
    </li>

</xsl:template>

<xsl:template match="eduaims">

    <li><b>Educational aims:</b><br />
        <xsl:apply-templates/>
    </li>

</xsl:template>

<xsl:template match="learningoutcome">

    <li><b>Learning Outcomes:</b><br />
        <xsl:for-each select="topic">
            <h3><xsl:value-of select="@title"/></h3>
            <ul>
                <xsl:for-each select="subtopic">
                    <li><xsl:apply-templates/></li>
                </xsl:for-each>
            </ul>
        </xsl:for-each>

        <xsl:if test="(@showtotals)='true'">
            <br /><xsl:value-of select="count(topic/subtopic)"/> 
            skills in total
        </xsl:if>
    </li>

</xsl:template>

<xsl:template match="subtopic">

    <xsl:apply-templates/>

</xsl:template>

<xsl:template match="resources">

    <li><b>Resources:</b></li>

</xsl:template>

<!-- Putting each para in <p> tags makes the gap between the last line and the <hr> larger than in the .pdf, so I used 2 x <br> -->

<xsl:template match="approval">

    <li><b>Approval by Head of School and other resource providers:</b>
        <xsl:for-each select="para">
            <br /><br /><xsl:value-of select="."/>
        </xsl:for-each>
    </li>

</xsl:template>

<!-- This template can be applied to whichever other template uses <emph> -->

<xsl:template match="emph">

    <b><xsl:value-of select="."/></b>

</xsl:template>

</xsl:stylesheet>